@@ -59,6 +59,18 @@ class Beaker:
         # Ensure default workspace exists.
         if self._config.default_workspace is not None:
             self.workspace.ensure(self._config.default_workspace)
+        # Validate default org.
+        if self._config.default_org is not None:
+            self.organization.get(self._config.default_org)
+
+    def __str__(self) -> str:
+        return (
+            f"Beaker("
+            f"user='{self.account.name}', "
+            f"default_workspace='{self.config.default_workspace}', "
+            f"default_org='{self.config.default_org}'"
+            f")"
+        )
 
     @staticmethod
     @cached(cache=TTLCache(maxsize=10, ttl=5 * 60))
